@@ -1,4 +1,4 @@
 from typeguard import typeguard_ignore
-from typeguard.importhook import install_import_hook
+from typeguard import install_import_hook
 
 install_import_hook('testudo')
