@@ -3,7 +3,7 @@ from pathlib import Path
 from shlex import split
 from subprocess import STDOUT, Popen, PIPE  # nosec
 from threading import Event
-from typing import List, Optional, Generator
+from typing import List, Optional, Generator, Union, Set
 
 from testudo.config import TaskConfig
 from testudo.log import log
@@ -38,8 +38,10 @@ class OutputWindow:
         return joined
 
 
-def run(db: Path, task_id: str, cmd: List[str]) -> bool:
+def run(db: Path, task_id: str, cmd: List[str],
+        success_codes: Optional[Union[List[int], Set[int]]] = None) -> bool:
     log.info(f"Running Task [{task_id}]...")
+    success_codes = success_codes or {0}
     out = OutputWindow(30)
     # this is the whole point of the program, to run arbitrary commands
     with Popen(cmd, stderr=STDOUT, stdout=PIPE, shell=False) as proc:  # nosec
@@ -57,7 +59,7 @@ def run(db: Path, task_id: str, cmd: List[str]) -> bool:
                     out.append(joined.rstrip())
                     line = []
         exit_code = proc.returncode
-        if exit_code == 0:
+        if exit_code in success_codes:
             log.info(f"Task [{task_id}] successful!")
             report_success(db, task_id, out.output)
             return True
@@ -71,11 +73,12 @@ def run_with_delay(db: Path, task_id: str,
                    delay_seconds: float,
                    halt_flag: Event,
                    initial_delay_seconds: Optional[float] = None,
-                   on_failure_delay_seconds: Optional[float] = None) -> Generator[bool, None, None]:
+                   on_failure_delay_seconds: Optional[float] = None,
+                   success_codes: Optional[List[int]] = None) -> Generator[bool, None, None]:
     on_failure_delay_seconds = on_failure_delay_seconds or delay_seconds
     halt_flag.wait(timeout=initial_delay_seconds or 0.0)
     while 42:
-        success = run(db, task_id, cmd)
+        success = run(db, task_id, cmd, success_codes)
         yield success
         if halt_flag.wait(delay_seconds if success else on_failure_delay_seconds):
             break
@@ -87,7 +90,8 @@ def run_with_reporter(db: Path, config: TaskConfig, halt: Optional[Event] = None
     for _ in run_with_delay(db, config.task_id, split(config.command),
                             delay_seconds=config.delay_seconds, halt_flag=_halt,
                             initial_delay_seconds=config.initial_delay_seconds,
-                            on_failure_delay_seconds=config.on_failure_delay_seconds):
+                            on_failure_delay_seconds=config.on_failure_delay_seconds,
+                            success_codes=config.acceptable_return_codes):
         if not first_run_complete:
             first_run_complete = True
             start_reporter_daemon(db, config, halt=_halt)
